@@ -20,9 +20,10 @@
 #
 # gen/proxy/__init__.py
 
-__all__ = [ "filter", "living", "private", "proxybase", "referenced" ]
+__all__ = [ "filter", "living", "private", "proxybase", "referencedbyselection" ]
 
 from .filter import FilterProxyDb
 from .living import LivingProxyDb
 from .private import PrivateProxyDb
 from .referencedbyselection import ReferencedBySelectionProxyDb
+from .cache import CacheProxyDb
