@@ -32,6 +32,7 @@ from gi.repository import Gtk
 from gramps.gui.editors import EditEvent
 from gramps.gui.listmodel import ListModel, NOSORT
 from gramps.gen.plug import Gramplet
+from gramps.gen.lib import (EventType, Date)
 from gramps.gen.plug.report.utils import find_spouse
 from gramps.gui.dbguielement import DbGUIElement
 from gramps.gen.display.place import displayer as place_displayer
@@ -84,13 +85,13 @@ class Events(Gramplet, DbGUIElement):
         titles = [('', NOSORT, 50,),
                   (_('Type'), 1, 100),
                   (_('Description'), 2, 150),
-                  (_('Date'), 3, 100),
+                  (_('Date'), 4, 100),
                   ('', NOSORT, 50),
-                  (_('Age'), 4, 100),
+                  (_('Age'), 6, 100),
                   ('', NOSORT, 50),
-                  (_('Place'), 5, 400),
-                  (_('Main Participants'), 6, 200),
-                  (_('Role'), 7, 100)]
+                  (_('Place'), 7, 400),
+                  (_('Main Participants'), 8, 200),
+                  (_('Role'), 9, 100)]
         self.model = ListModel(top, titles, event_func=self.edit_event)
         return top
 
@@ -129,7 +130,12 @@ class Events(Gramplet, DbGUIElement):
         date = event.get_date_object()
         start_date = self.cached_start_date
         if date and start_date:
-            return (date - start_date).format(precision=age_precision)
+            if (date == start_date and date.modifier == Date.MOD_NONE
+                    and not (event.get_type().is_death_fallback() or
+                             event.get_type() == EventType.DEATH)):
+                return ""
+            else:
+                return (date - start_date).format(precision=age_precision)
         else:
             return ""
 
